DROP TABLE IF EXISTS downloads;

CREATE TABLE downloads (
  _id integer PRIMARY KEY  NOT NULL,
  pvr_id text,
  crid text,
  event_id text,
  service_id text,
  recorded_duration integer DEFAULT (0),
  src text,
  status text,
  recorded_size integer DEFAULT (0) ,
  last_played_position integer DEFAULT (-1) ,
  start_of_credits_marker_milliseconds integer DEFAULT (0),
  is_fully_watched integer DEFAULT(0),
  title text,
  synopsis text,
  broadcast_time integer DEFAULT (0),
  rating text,
  metadata_rating text,
  channel_number text,
  channel_name text,
  expiration_date text,
  program_uuid text,
  season_uuid text,
  series_uuid text,
  episode_name text,
  episode_number integer DEFAULT (0),
  season_number integer DEFAULT (0),
  record_id integer DEFAULT (0),
  available_size integer,
  available_duration integer,
  total_size integer,
  total_duration integer,
  last_status_changed_time integer,
  url text,
  transaction_id text,
  has_subtitle integer DEFAULT(0),
  ottdownloadable integer DEFAULT (0),
  local_time_offset_seconds integer DEFAULT (0)
  );

DROP TABLE IF EXISTS pvr;

CREATE TABLE pvr (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  pvr_id text,
  downloadlink text,
  event_id text,
  service_id text,
  recorded_duration integer DEFAULT(0),
  src text,
  status text,
  deleted integer DEFAULT(0),
  keep integer DEFAULT(0),
  lock integer DEFAULT(0),
  serieslinked integer DEFAULT(0),
  can_series_link integer DEFAULT(0),
  recorded_size integer DEFAULT(0),
  failure_reason text,
  last_played_position integer DEFAULT(-1),
  title text,
  synopsis text,
  scheduled_start_time integer,
  actual_start_time integer DEFAULT(0),
  local_time_offset integer DEFAULT(0),
  event_genre text,
  event_sub_genre text,
  rating text,
  audio_type text,
  subtitles integer DEFAULT(0),
  audio_description integer DEFAULT(0),
  hd integer DEFAULT(0),
  format_3d integer DEFAULT(0),
  widescreen integer DEFAULT(0),
  channel_number text,
  channel_name text,
  expiry_time integer DEFAULT(0),
  type text,
  program_uuid text,
  season_uuid text,
  series_uuid text,
  pushed_programme_id text,
  episode_number integer DEFAULT(0),
  season_number integer DEFAULT(0),
  tso_title text,
  last_played_time integer,
  sla integer,
  slo integer DEFAULT(0),
  caviewed integer DEFAULT(0),
  audio_recording integer DEFAULT(0),
  vod_programme_id text,
  scheduled_duration integer DEFAULT(0),
  predicted_size integer DEFAULT(0),
  pvod_saved integer DEFAULT(0),
  gap_in_recording integer DEFAULT(0),
  marketing_message text,
  trailer_available integer DEFAULT(0),
  is_child integer DEFAULT(0),
  purchase_required integer DEFAULT(0),
  boxset_id text,
  et text,
  programme_imageuri_16x9 text,
  programme_imageuri_3x4 text,
  adult integer DEFAULT(0)
);

DROP TABLE IF EXISTS schedule;

CREATE TABLE schedule (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  service_id text NOT NULL,
  date text NOT NULL,
  eid text NOT NULL,
  start_time integer DEFAULT(0),
  has_children integer DEFAULT(0),
  title text NOT NULL,
  duration integer DEFAULT(0),
  synopsis text,
  event_genre text NOT NULL,
  event_sub_genre text NOT NULL,
  rating text,
  audio_type text NOT NULL,
  subtitles integer DEFAULT(0),
  audio_description integer DEFAULT(0),
  hd integer DEFAULT(0),
  widescreen integer DEFAULT(0),
  new integer DEFAULT(0),
  can_series_link integer DEFAULT(0),
  can_book integer DEFAULT(0),
  image_uri text,
  program_uuid text,
  season_uuid text,
  series_uuid text,
  episode_number integer DEFAULT(0),
  season_number integer DEFAULT(0),
  et text
);

DROP TABLE IF EXISTS remote_recordings;

CREATE TABLE remote_recordings (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  event_id text NOT NULL UNIQUE,
  series_linked integer DEFAULT(0)
);

CREATE INDEX remote_recordings_event_id_idx ON remote_recordings (event_id);


DROP TABLE IF EXISTS remote_downloads;

CREATE TABLE remote_downloads (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  programme_id text NOT NULL UNIQUE
);

CREATE INDEX remote_downloads_programme_id_idx ON remote_downloads (programme_id);

DROP TABLE IF EXISTS services;

CREATE TABLE services (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  service_id text NOT NULL,
  channel_number integer NOT NULL,
  title text NOT NULL,
  genre text NOT NULL,
  format text NOT NULL COLLATE NOCASE,
  adult integer DEFAULT(0 ),
  service_type text,
  available_ott integer DEFAULT(0 ),
  available_broadcast integer DEFAULT(0 )
);

DROP TABLE IF EXISTS versions;

CREATE TABLE versions (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  table_name text NOT NULL,
  document_id text NOT NULL,
  version integer DEFAULT(0)
);

CREATE TABLE ottdigest (
    _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
    program_uuid text,
    streamable integer DEFAULT(0),
    downloadable integer DEFAULT(0)
);

CREATE TABLE ott (
    _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
    programme_id text,
    last_played_position integer DEFAULT(-1),
    is_fully_watched integer DEFAULT(0),
    expiration_date integer DEFAULT(-1),
    last_played_position_server integer DEFAULT(-1),
    last_played_timestamp_server integer DEFAULT (0),
    last_played_timestamp integer DEFAULT (0),
    uuid text,
    becs_enriched integer DEFAULT(0)
);

DROP TABLE IF EXISTS boxset;

CREATE TABLE boxset (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  boxset_id text NOT NULL UNIQUE,
  t text,
  tso integer DEFAULT(0),
  sy text,
  series_linked integer DEFAULT(0),
  r text,
  imageuri_16x9 text,
  imageuri_3x4 text,
  renderhints text
);

-- programme metadata

DROP TABLE IF EXISTS bookmark_metadata;

CREATE TABLE bookmark_metadata (
  _id integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  episode_number integer DEFAULT(0),
  season_number integer DEFAULT(0),
  season_title text,
  season_uuid text,
  series_title text,
  series_uuid text,
  description text,
  title text,
  trailer integer DEFAULT(0),
  type text,
  uuid text,
  uuid_type text,
  content_id text,
  has_audio_description integer,
  added_time integer,
  audio_type text,
  channel_group_id text,
  channel_group_name text,
  channel_name text,
  duration integer,
  start_of_credits_millis integer,
  is_3d integer,
  programme_id text,
  provider_id text,
  provider_name text,
  has_subtitles integer,
  service_id text,
  file_size integer,
  synopsis text,
  video_type text,
  rating text,
  download_available_end_time_seconds integer DEFAULT(-1),
  streaming_available_end_time_seconds integer DEFAULT(-1)
);

CREATE INDEX bookmark_metadata_content_id ON bookmark_metadata(content_id);